@@ -4,19 +4,16 @@ use std::{
     task::{Context, Poll},
 };
 
-use crate::{
-    receiver::{Action, Event, ReciveTypedReceiver, SendUntypedReceiver},
-    receivers::{fix_type, Request},
-    synchronized_poller_macro,
-};
-use anyhow::Result;
-use futures::{executor::block_on, Future};
+use crate::synchronized_poller_macro;
+use futures::{Future, executor::block_on};
 
 use super::SynchronizedConfig;
 use crate::{
+    error::{Error, StdSyncSendError, SendError},
     builder::ReceiverSubscriberBuilder,
-    receiver::{SendError, SendTypedReceiver},
-    Bus, Message, SynchronizedHandler, Untyped,
+    receiver::{SendTypedReceiver, Action, Event, ReciveTypedReceiver, SendUntypedReceiver},
+    receivers::{fix_type, Request},
+    SynchronizedHandler, Bus, Message, Untyped,
 };
 use tokio::sync::{mpsc, Mutex};
 
@@ -37,11 +34,11 @@ synchronized_poller_macro! {
     }
 }
 
-pub struct SynchronizedSync<M, R = (), E = crate::error::Error>
+pub struct SynchronizedSync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     tx: mpsc::UnboundedSender<Request<M>>,
     srx: parking_lot::Mutex<mpsc::UnboundedReceiver<Event<R, E>>>,
@@ -52,7 +49,7 @@ where
     T: SynchronizedHandler<M, Response = R, Error = E> + 'static,
     R: Message,
     M: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     type Config = SynchronizedConfig;
 
@@ -69,7 +66,7 @@ where
 
         let poller = Box::new(move |ut| {
             Box::new(move |bus| {
-                Box::pin(synchronized_poller::<T, M, R, E>(rx, bus, ut, stx))
+                Box::pin(synchronized_poller::<T, M, R>(rx, bus, ut, stx))
                     as Pin<Box<dyn Future<Output = ()> + Send>>
             }) as Box<dyn FnOnce(Bus) -> Pin<Box<dyn Future<Output = ()> + Send>>>
         });
@@ -88,7 +85,7 @@ impl<M, R, E> SendUntypedReceiver for SynchronizedSync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     fn send(&self, msg: Action) -> Result<(), SendError<Action>> {
         match self.tx.send(Request::Action(msg)) {
@@ -103,7 +100,7 @@ impl<M, R, E> SendTypedReceiver<M> for SynchronizedSync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     fn send(&self, mid: u64, m: M) -> Result<(), SendError<M>> {
         match self.tx.send(Request::Request(mid, m)) {
@@ -118,7 +115,7 @@ impl<M, R, E> ReciveTypedReceiver<R, E> for SynchronizedSync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     fn poll_events(&self, ctx: &mut Context<'_>) -> Poll<Event<R, E>> {
         let poll = self.srx.lock().poll_recv(ctx);
